@@ -95,8 +95,8 @@ def get_access_token():
 
 app_id = get_app_id()
 
-def get_ingestion_config():
-    url = f"https://{app_url}/app/{app_id}/ingestionConfig"
+def get_ingestion_config(ingestion_config_id):
+    url = f"https://{app_url}/app/{app_id}/ingestionConfig/{ingestion_config_id}"
     access_token = get_access_token()
     headers = {
         "x-dassana-tenant-id": tenant_id,
@@ -105,20 +105,19 @@ def get_ingestion_config():
     if app_url.endswith("svc.cluster.local:443"):
         response = requests.request("GET", url, headers=headers, verify=False)
         try:
-            ingestion_config = response.json()[0] 
+            ingestion_config = response.json()
         except:
             raise InternalError(url, response.json())
         return ingestion_config
     else:
         response = requests.request("GET", url, headers=headers)
         try:
-            ingestion_config = response.json()[0] 
+            ingestion_config = response.json() 
         except:
             raise InternalError(url, response.json())
         return ingestion_config
 
-def patch_ingestion_config(payload):
-    ingestion_config_id = get_ingestion_config()['id']
+def patch_ingestion_config(payload, ingestion_config_id):
     url = f"https://{app_url}/app/{app_id}/ingestionConfig/{ingestion_config_id}"
     access_token = get_access_token()
     headers = {
@@ -161,8 +160,8 @@ def get_dassana_token():
 dassana_token = get_dassana_token()
 os.environ["DASSANA_TOKEN"] = dassana_token
 
-def report_status(status, additionalContext, timeTakenInSec, recordsIngested):
-    reportingURL = f"https://{app_url}/app/{app_id}/status"
+def report_status(status, additionalContext, timeTakenInSec, recordsIngested, ingestion_config_id):
+    reportingURL = f"https://{app_url}/app/v1/{app_id}/status"
 
     headers = {
         "x-dassana-tenant-id": tenant_id,
@@ -173,6 +172,7 @@ def report_status(status, additionalContext, timeTakenInSec, recordsIngested):
         "status": status,
         "timeTakenInSec": int(timeTakenInSec),
         "recordsIngested": recordsIngested,
+        "ingestionConfigId": ingestion_config_id
     }
 
     if additionalContext:
@@ -192,11 +192,14 @@ def datetime_handler(val):
         return val.isoformat()
     return str(val)
 
-def forward_logs(
-    log_data
-):
+def forward_logs(log_data,type="findings"):    
+    if type == 'findings':
+        endpoint = f"{os.environ['DASSANA_ENDPOINT']}/findings"
+    elif type == 'assets':
+        endpoint = f"{os.environ['DASSANA_ENDPOINT']}/assets"
+    elif type == 'events':
+        endpoint = f"{os.environ['DASSANA_ENDPOINT']}/events"
 
-    endpoint=get_endpoint()
     app_id=get_app_id()
     use_ssl=get_ssl()
     token = get_token()
@@ -282,4 +285,3 @@ def acknowledge_delivery():
     subscriber.acknowledge(
         request={"subscription": subscription_path, "ack_ids": ack_ids}
     )
-
